Class: Tuile::Component::PickerWindow::Option
- Inherits:
-
Object
- Object
- Tuile::Component::PickerWindow::Option
- Defined in:
- lib/tuile/component/picker_window.rb,
sig/tuile.rbs
Overview
One picker option.
Instance Attribute Summary collapse
-
#caption ⇒ StyledString
readonly
@return — the option caption, coerced from whatever the constructor was handed.
-
#key ⇒ String
readonly
@return — the keyboard key that picks this option.
Instance Attribute Details
#caption ⇒ StyledString (readonly)
@return — the option caption, coerced from whatever the constructor was handed.
38 39 |
# File 'lib/tuile/component/picker_window.rb', line 38 class Option < Data.define(:key, :caption) end |
#key ⇒ String (readonly)
@return — the keyboard key that picks this option.
38 39 |
# File 'lib/tuile/component/picker_window.rb', line 38 class Option < Data.define(:key, :caption) end |