Class: Tuile::EventQueue::EmptyQueueEvent
- Inherits:
-
Object
- Object
- Tuile::EventQueue::EmptyQueueEvent
- Includes:
- Singleton
- Defined in:
- lib/tuile/event_queue.rb
Overview
Emitted once when the queue is cleared, all messages are processed and the event loop will block waiting for more messages. Perfect time for repainting windows.