Class: Tuile::Component::LogWindow::IO

Inherits:
Object
  • Object
show all
Defined in:
lib/tuile/component/log_window.rb

Overview

IO-shaped adapter that forwards each log line to the owning Tuile::Component::LogWindow. Implements both #write (stdlib ‘Logger`) and #puts (loggers that call `output.puts`, e.g. `TTY::Logger`).

Instance Method Summary collapse

Constructor Details

#initialize(window) ⇒ IO

Returns a new instance of IO.

Parameters:



31
32
33
# File 'lib/tuile/component/log_window.rb', line 31

def initialize(window)
  @window = window
end

Instance Method Details

#closevoid

This method returns an undefined value.

Stdlib ‘Logger` only treats an object as an IO target when it responds to both #write and #close; otherwise it tries to interpret it as a filename. This is a no-op.



55
# File 'lib/tuile/component/log_window.rb', line 55

def close; end

#puts(string) ⇒ void

This method returns an undefined value.

Parameters:

  • string (String)


45
46
47
48
49
# File 'lib/tuile/component/log_window.rb', line 45

def puts(string)
  @window.screen.event_queue.submit do
    @window.content.add_line(string)
  end
end

#write(string) ⇒ void

This method returns an undefined value.

Parameters:

  • string (String)


37
38
39
40
41
# File 'lib/tuile/component/log_window.rb', line 37

def write(string)
  @window.screen.event_queue.submit do
    @window.content.add_line(string.chomp)
  end
end